@@ -4,27 +4,22 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 require XSLoader;
 XSLoader::load("Basic::Types::XS", $VERSION);
 
-sub import {
-	my ($caller, $pkg, @export) = (scalar caller(), @_);
-	_install($caller, @export);
-}
-
 1;
 
 __END__
 
 =head1 NAME
 
-Basic::Types::XS - The great new Basic::Types::XS!
+Basic::Types::XS - Fast but limited type constraints
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -186,6 +181,18 @@ Value that contain glob references
 
 =cut
 
+=head3 Object
+
+Values that contain blessed references (objects).
+
+	Object->(My::Class->new());
+
+=head3 ClassName
+
+Values that contain valid class names (strings).
+
+	ClassName->("My::Class");
+
 =head1 METHODS
 
 =head2 validate
